@@ -59,7 +59,7 @@
 //! use nom_locate::LocatedSpan;
 //! type Span<'a> = LocatedSpan<&'a str, String>;
 //!
-//! let input = Span::new("Lorem ipsum \n foobar", "filename");
+//! let input = Span::new_extra("Lorem ipsum \n foobar", "filename");
 //! let output = parse_foobar(input);
 //! let extra = output.unwrap().1.extra;
 //! ```
@@ -149,6 +149,16 @@ impl<T, X> core::ops::Deref for LocatedSpan<T, X> {
     }
 }
 
+impl<T, U, X> core::convert::AsRef<U> for LocatedSpan<&T, X>
+where
+    T: ?Sized + core::convert::AsRef<U>,
+    U: ?Sized,
+{
+    fn as_ref(&self) -> &U {
+        self.fragment.as_ref()
+    }
+}
+
 #[cfg(feature = "stable-deref-trait")]
 /// Optionally impl StableDeref so that this type works harmoniously with other
 /// crates that rely on this marker trait, such as `rental` and `lazy_static`.
@@ -157,7 +167,7 @@ impl<T, X> core::ops::Deref for LocatedSpan<T, X> {
 /// StableDeref.
 unsafe impl<T: StableDeref, X> StableDeref for LocatedSpan<T, X> {}
 
-impl<T: AsBytes> LocatedSpan<T, ()> {
+impl<T> LocatedSpan<T, ()> {
     /// Create a span for a particular input with default `offset` and
     /// `line` values and empty extra data.
     /// You can compute the column through the `get_column` or `get_utf8_column`
@@ -195,7 +205,7 @@ impl<T: AsBytes> LocatedSpan<T, ()> {
     }
 }
 
-impl<T: AsBytes, X> LocatedSpan<T, X> {
+impl<T, X> LocatedSpan<T, X> {
     /// Create a span for a particular input with default `offset` and
     /// `line` values. You can compute the column through the `get_column` or `get_utf8_column`
     /// methods.
@@ -268,6 +278,52 @@ impl<T: AsBytes, X> LocatedSpan<T, X> {
         &self.fragment
     }
 
+    /// Transform the extra inside into another type
+    ///
+    /// # Example of use
+    /// ```
+    /// # extern crate nom_locate;
+    /// # extern crate nom;
+    /// # use nom_locate::LocatedSpan;
+    /// use nom::{
+    ///   IResult,
+    ///   combinator::{recognize, map_res},
+    ///   sequence::{terminated, tuple},
+    ///   character::{complete::{char, one_of}, is_digit},
+    ///   bytes::complete::{tag, take_while1}
+    /// };
+    ///
+    /// fn decimal(input: LocatedSpan<&str>) -> IResult<LocatedSpan<&str>, LocatedSpan<&str>> {
+    ///   recognize(
+    ///        take_while1(|c| is_digit(c as u8) || c == '_')
+    ///   )(input)
+    /// }
+    ///
+    /// fn main() {
+    ///     let span = LocatedSpan::new("$10");
+    ///     // matches the $ and then matches the decimal number afterwards,
+    ///     // converting it into a `u8` and putting that value in the span
+    ///     let (_, (_, n)) = tuple((
+    ///                         tag("$"),
+    ///                         map_res(
+    ///                             decimal,
+    ///                             |x| x.fragment().parse::<u8>().map(|n| x.map_extra(|_| n))
+    ///                         )
+    ///                       ))(span).unwrap();
+    ///     assert_eq!(n.extra, 10);
+    /// }
+    /// ```
+    pub fn map_extra<U, F: FnOnce(X) -> U>(self, f: F) -> LocatedSpan<T, U> {
+        LocatedSpan {
+            offset: self.offset,
+            line: self.line,
+            fragment: self.fragment,
+            extra: f(self.extra),
+        }
+    }
+}
+
+impl<T: AsBytes, X> LocatedSpan<T, X> {
     // Attempt to get the "original" data slice back, by extending
     // self.fragment backwards by self.offset.
     // Note that any bytes truncated from after self.fragment will not
